import re

class SubscriberChannel:
    def __call__(self, *args, **kwargs):
        self.callback(*args, **kwargs)
    def setTopic(self, topic, channelName=None):
        self.topic = topic
    def setOnConsumeCallback(self, callback):
        self.callback = callback

class MessageChannel:
    def setTopic(self, topic):
        self.topic = topic
    def close(self):
        pass
    def send(self, message) -> None:
        pass


def extractChannelNameFromPropertyKey(key):
    matches = re.match(
        "rcn.binders.message.(?P<defaultBinder>[a-z]+).(?P<binderType>(\w)+).(?P<channelName>[a-z0-9\-\_]+).[destination|property]",
        key.lower())
    if matches is not None:
        return matches.groupdict()['channelName']
    return None


class InvalidBeanDefination(Exception):
    def __init__(self, message):
        super().__init__(self, message)

class BeanNotFoundException(Exception):
    def __init__(self, message):
        super(BeanNotFoundException, self).__init__(message)



RCN_EVENTS_ENABLE = "rcn.events.enable"
RCN_EVENTS_WAITTIME = "rcn.events.waittime"
RCN_EVENTS_INVOKER_SLEEP_TIME = "rcn.events.expected.invoker.time"

RCN_FLASK_APP_ENABLED = "app.flask.enabled"
RCN_FLASK_APP_NAME = "app.flask.name"
RCN_FLASK_APP_PORT = "app.flask.port"
RCN_FLASK_APP_LISTEN = "app.flask.listen"
RCN_FLASK_APP_CONTEXT_URL = "app.flask.contextUrl"
RCN_FLASK_APP_CONFIGS_LIST = "app.flask.configs"
RCN_FLASK_APP_BACKEND_SERVER = "app.flask.backend"